@@ -6,10 +6,11 @@ class CLIUsageCommand(Command):
     """Command to parse CLI usage into Markdown."""
 
     def build_index(self):
+        print('## Table of Contents\n')
         for folder in self.config['folders']:
-            print("- [" + folder['title'].title() + "](#" + folder['title'] + ')\n')
+            print("- [" + folder['title'].title() + "](#" + folder['title'] + ')')
             for command in folder['commands']:
-                print("    * [" + command + "](#" + command + ')\n')
+                print("    * [" + command + "](#" + command + ')')
 
     def build_commands(self):
         for folder in self.config['folders']:
@@ -17,7 +18,7 @@ class CLIUsageCommand(Command):
             for command in folder['commands']:
                 print('### ' + command + '\n')
                 cli_command = "symbol-cli " + folder['title'] + " " + command + " -h"
-                process = subprocess.run(cli_command, shell=True, text=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+                process = subprocess.run(cli_command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
                 print(process.stdout)
 
     def execute(self):
